@@ -1,6 +1,6 @@
 #' @importFrom utils getFromNamespace
 launch_yaml_addin <- function() {
-  stop_if_not_installed(c("miniIU", "shinyBS"))
+  stop_if_not_installed(c("miniUI", "shinyBS"))
   addin_dir <- system.file("addin", "new_yaml", package = "ymlthis")
   app <- shiny::shinyAppDir(addin_dir)
   shiny::runGadget(
@@ -8,3 +8,4 @@ launch_yaml_addin <- function() {
     viewer = shiny::dialogViewer("New YAML", height = 700)
   )
 }
+
